@@ -1,5 +1,6 @@
 from tamarin.elasticsearch.client import ElasticSearchClient
 from .config import CURRENT_TIME_ZONE, ALLOWED_STATUS
+from tamarin.elasticsearch.utils.functions import validate_status
 from tamarin.command import Command
 from sentry_sdk import capture_exception
 import uuid
@@ -22,7 +23,7 @@ class ElasticSearchCommand(Command):
 
     def execute(self):
         try:
-            if self._status_code in ALLOWED_STATUS:
+            if validate_status(self._status_code):
                 response = self._response
                 metadata = response.get('metadata')
                 transaction = metadata.pop('transaction', {})
